--First it's important that we keep track of whether BattleMod has been loaded so that we can tell the game when to create our function.
--To do this, we're going to start off by creating a local variable.
local ScriptLoaded = false

--Now let's encase the rest of our code inside of ThinkFrame...
addHook("ThinkFrame", function()
	--... so that we can check each frame to see if the script has been loaded yet.
	if not(ScriptLoaded)
		and CBW_Battle --CBW_Battle is the master table for all of BattleMod's functions. Attempting to run our scripts without Battle loaded will result in a lua error, so we have to check before trying to run the rest of the code.
		then
		ScriptLoaded = true 
		local B = CBW_Battle --Just for convenience, we're going to truncate this table; it'll make writing functions a little less cumbersome.
				
		--Now let's create our action.
		local Tondeker = function(mo,doaction)
			/* Notes on action functions
			Action functions follow the format of (mo,doaction).
			mo is the player object that is performing the action.
			doaction is the state of whether the player is attempting to perform an action or not, depending on current key inputs.
				0 = no button pressed
				1 = button has been pressed and action can be performed
				2 = button is being held down and action can be performed
				-1 = Player is attempting to perform an action, but can't because of one of the following conditions:
					- The player is exiting the level
					- The player's action is on cooldown
					- The player character is in pain
					- The player's controls have been disabled
					- The player is "not it" in tag mode
					- The player has the flag in CTF or the crystal in Diamond in the Rough
			*/
			local player = mo.player
			
			--Now for some definitions:
			player.actiontext = "Tondeker" --This is the HUD text that appears next to the red ring icon.
			player.actionrings = 5 --This is the amount of rings your action costs, and will also display in the HUD if set above 0.
			player.action2text = nil --If a string is defined, this will display below the first string, next to the flag icon.
			player.action2rings = 0  --"ring amount" displayed next to action2text, if applicable. Unused by default, but still available as a HUD item.
			--Note that these variables are reset on every frame to nil or 0.
			
			if not(B.CanDoAction(player))
				then
				player.actionstate = 0 --Default action state
				return end	
	
				if player.actionstate == 0 and doaction == 1
					player.actionstate = 1 --This moves us onto the next actionstate
					player.actiontime = 0 --This can be used to keep track of time in a certain state. Unlike its name suggests, this variable does NOT automatically tic up or down, so you will have to add or subtract from this variable manually if you want it to operate like a timer.
					B.PayRings(player) --Spend actionring amount and plays the anti-ring sfx.
				end

				if player.actionstate == 1
					player.actiontime = $+1
				end

				if player.actiontime == 2 then
					player.actionstate = 2
					player.actiontime = 0
				end

				if player.actionstate == 2
				player.mo.state = S_PLAY_FIRE
				local an = player.mo.angle
				local slope = player.aiming
				S_StartSound(player.mo, sfx_tndk)
				local th = P_SpawnMobj(player.mo.x + (1*cos(an)), player.mo.y + (1*sin(an)), player.mo.z+20*FRACUNIT, MT_TONDEKER)
				th.scale = player.mo.scale
				th.target = player.mo
				th.color = player.mo.color
				local speed = 50*FRACUNIT
				th.angle = an
				th.momx = FixedMul(speed, cos(an))
				th.momy = FixedMul(speed, sin(an))
				th.momx = FixedMul(th.momx, cos(slope))
				th.momy = FixedMul(th.momy, cos(slope))
				th.momz = FixedMul(speed, sin(slope))
				player.actiontime = 5
				
				B.ApplyCooldown(player,TICRATE*1) --Waittime before player can use this action again. If the player used this action without any rings on-hand, the waittime is doubled.				
				--Reset player state
				if player.actiontime == 5
					player.actionstate = 0
				end
			end
		end

		local PriorityFunc = function(player)
			if player.actionstate == 2 then
				B.SetPriority(player,1,3,nil,1,3,"Tondeker")				-- In this instance, the player will have an attack priority of 1 and a defense priority of 3 so long as his actionstate is 1.
			end
		end

		CBW_Battle.SkinVars["sukapon"] = {
			flags = SKINVARS_GUARD,
			weight = 80,
			shields = 0,
			special = Tondeker,
			func_priority_ext = PriorityFunc
		}
	end
end)
addHook("HurtMsg",function(player,inflictor,source) print(CBW_Battle.CustomHurtMessage(player,source,"Tondeker")) return true end, MT_TONDEKER)